<h3>Documentation</h3>
<ul>
<li><a href="{{ pathto("contents") }}">Table of Contents</a></li>
<li><a href="{{ pathto("changes") }}">Changelog</a></li>
<li><a href="{{ pathto("readme") }}">Documentation</a></li>
<li><a href="{{ pathto("install") }}">Installation</a></li>
<li><a href="{{ pathto("keybinds") }}">Keybinds</a></li>
</ul>

<h3>Examples</h3>
<ul>
<li><a href="{{ pathto("screenshots") }}">Screenshots</a></li>
</ul>

<h3>Resources</h3>
<ul>
<li><a href="http://labs.feurix.org/admin/hatop/">Development</a></li>
<li><a href="http://labs.feurix.org/admin/hatop/tree/">Development Tree</a></li>
<li><a href="http://labs.feurix.org/admin/hatop/log/">Complete Changelog</a></li>
</ul>

<h3>Downloads</h3>
<ul>
<li><a href="http://hatop.googlecode.com/files/hatop-{{ version }}.tar.gz">Latest Version: v{{ version }}</a></li>
<li><a href="http://code.google.com/p/hatop/downloads/list" target="_blank">Older Versions</a></li>
<li><a href="http://labs.feurix.org/admin/hatop/snapshot/master.tar.gz">Snapshot</a></li>
</ul>

<h3>Contact us</h3>
<ul><li><a href="mailto:info@feurix.com">info@feurix.com</a></li></ul>

<h3>Support us</h3>
<form action="https://www.paypal.com/cgi-bin/webscr" method="post">
    <input type="hidden" name="cmd" value="_s-xclick" />
    <input type="hidden" name="hosted_button_id" value="10699425" />
    <input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donateCC_LG.gif"
      name="submit" alt="Donate using Paypal" class="donate" />
    <img alt="" border="0" src="https://www.paypal.com/de_DE/i/scr/pixel.gif"
      width="1" height="1" />
</form>
