{% extends "defindex.html" %}
{% block body %}
<h1>{{ docstitle|e }}</h1>
<a href="http://www.gnu.org/licenses/gpl-3.0.html">
  <img src="{{ pathto('_static/gplv3.png', 1) }}" alt="GPLv3 License" style="float: right" />
</a>
<p>
Welcome! This is
{% block description %}the documentation for {{ project|e }}
version {{ release|e }}{% if last_updated %}, last updated {{ last_updated|e }}{% endif %}{% endblock %}.
</p>

<p class="primer"><strong>What is HATop?</strong></p>
<p class="description">
<strong>
  HATop is an interactive ncurses client and real-time monitoring,<br />
  statistics displaying tool for the
  <a href="http://haproxy.1wt.eu/" target="_blank">HAProxy</a>
  TCP/HTTP load balancer.
</strong>
</p>

<p class="description">
HATop's appearance is similar to
<a href="http://en.wikipedia.org/wiki/Top_%28Unix%29" target="_blank">top</a>(1).
It supports various modes for detailed statistics of all configured proxies
and services in near realtime. In addition, it features an interactive CLI for
the haproxy unix socket. This allows administrators to control the given
haproxy instance (change server weight, put servers into maintenance mode, ...)
directly out of hatop (using keybinds or the CLI) and monitor the results
immediately.
</p>

<p class="description">
HATop is written in pure <a href="http://www.python.org/" target="_blank">Python</a>
and has no external dependencies.<br />
It requires Python 2.4 or later and HAProxy 1.4 or later.
</p>

<p>
  <strong>
  <a class="download" href="http://hatop.googlecode.com/files/hatop-{{ version }}.tar.gz">
    <img src="{{ pathto('_static/disk.png', 1) }}" alt="Download" />
    Download HATop v{{ version }} [hatop-{{ version }}.tar.gz]
  </a>
  </strong>
</p>

<hr />

{% block tables %}
<p><strong>Documentation:</strong></p>
<table class="contentstable" align="center">
  <tr>
    <td width="50%">
      <p class="biglink"><a class="biglink" href="{{ pathto("changes") }}">What's new in HATop v{{ version }}?</a><br/>
      <span class="linkdescr">or see <a href="http://labs.feurix.org/admin/hatop/log/">the complete changelog</a></span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("contents") }}">Complete Table of Contents</a><br/>
      <span class="linkdescr">lists all sections and subsections</span></p>
    </td>
    <td width="50%">
      <p class="biglink"><a class="biglink" href="{{ pathto("screenshots") }}">Screenshots</a><br/>
      <span class="linkdescr">some screenshots</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("keybinds") }}">Keybinds</a><br/>
      <span class="linkdescr">keybind quickref</span></p>
    </td>
  </tr>
</table>

<p><strong>Meta information:</strong></p>
<table class="contentstable" align="center">
  <tr>
    <td width="50%">
      <p class="biglink"><a class="biglink" href="{{ pathto("license") }}">License and Copyright</a><br />
      <span class="linkdescr">how you may use the code</span></p>
      </td><td width="50%">
      <p class="biglink"><a class="biglink" href="{{ pathto("bugs") }}">Reporting bugs</a><br />
      <span class="linkdescr">please inform us of any problems</span></p>
    </td>
  </tr>
</table>
{% endblock %}

<h2>Quickstart<a class="headerlink" href="#quickstart" title="Permalink to this headline">¶</a></h2>

<p class="description">
First of all, make sure you have the stats socket enabled in the haproxy config:
</p>
<div class="highlight">
<pre>global
  stats socket /var/run/haproxy/haproxy.sock mode 0600 level admin
</pre>
</div>

<p class="description">
That's all you need to use HATop:
</p>
<div class="highlight">
<pre>
$ hatop -s /var/run/haproxy/haproxy.sock
</pre>
</div>

<p>
  See also:
  <a class="reference internal" href="{{ pathto("install") }}"><em>HATop Installation</em></a>
</p>

<h2>Development<a class="headerlink" href="#development" title="Permalink to this headline">¶</a></h2>

<p class="description">
Getting the HATop source code using Git:
</p>
<div class="highlight">
<pre>
$ git clone git://labs.feurix.org/feurix/admin/hatop.git
</pre>
</div>

<p>
  See also:
  <a href="http://labs.feurix.org/admin/hatop/" target="_blank"><em>Git Webinterface</em></a>,
  <a href="http://labs.feurix.org/admin/hatop/tree/" target="_blank"><em>Source Browser</em></a>
</p>

{% endblock %}
